==> subtitlecomposer-0.4.1.tar.bz2: subtitlecomposer-0.4.1/src/core/audiolevels.h <==
#ifndef AUDIOLEVELS_H
#define AUDIOLEVELS_H

/***************************************************************************
 *   Copyright (C) 2007-2008 by Sergio Pistone                             *
 *   sergio_pistone@yahoo.com.ar                                           *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#ifdef HAVE_CONFIG_H
	#include <config.h>
#endif

#include <sctime.h>

#include <qobject.h>

#include <kdebug.h>
#include <kurl.h>

namespace SubtitleComposer
{
	class AudioLevels : public QObject
	{
		Q_OBJECT

		public:

			AudioLevels();
			virtual ~AudioLevels();

			bool load( const QString& filePath );
			bool loadFromMedia( const QString& mediaPath, unsigned streamIndex );
			bool save( const QString& filePath, bool overwrite ) const;

			void reset();

			inline unsigned channelsCount() const
			{
				return m_channelsCount;
			};

			inline unsigned samplesCount() const // in milliseconds
			{
				return m_samplesCount;
			};

			inline unsigned samplesInterval() const // in milliseconds
			{
				return m_samplesInterval;
			};

			inline Time length() const // in milliseconds
			{
				return m_samplesCount*m_samplesInterval;
			};

			/// warning!! no checks performed!
			inline double dataBySample( unsigned channel, unsigned sample ) const
			{
				//return sample >= m_samplesCount ? 0 : m_samplesData[m_samplesCount*channel+sample];
				return m_samplesData[m_samplesCount*channel+sample];
			};

			inline double dataByPosition( unsigned channel, const Time& position ) const
			{
				int dataIndex = m_samplesCount*channel+position.toMillis()/m_samplesInterval;
				return dataIndex > m_lastDataIndex ? 0 : m_samplesData[dataIndex];
			};

			inline unsigned sampleForPosition( const Time& position ) const
			{
				if ( position > length() )
					return m_samplesCount - 1;

				return position.toMillis()/m_samplesInterval;
			};

		signals:

			void loadProgress( int percentage );

		private:

			unsigned m_channelsCount;
			unsigned m_samplesInterval;
			unsigned m_samplesCount;
			double* m_samplesData;
			int m_lastDataIndex;
			KURL m_mediaUrl;
	};
}

#endif

==> subtitlecomposer-0.4.2.tar.bz2: subtitlecomposer-0.4.2/src/core/audiolevels.h <==
#ifndef AUDIOLEVELS_H
#define AUDIOLEVELS_H

/***************************************************************************
 *   Copyright (C) 2007-2008 by Sergio Pistone                             *
 *   sergio_pistone@yahoo.com.ar                                           *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#ifdef HAVE_CONFIG_H
	#include <config.h>
#endif

#include <sctime.h>

#include <qobject.h>

#include <kurl.h>

namespace SubtitleComposer
{
	class AudioLevels : public QObject
	{
		Q_OBJECT

		public:

			AudioLevels();
			virtual ~AudioLevels();

			bool load( const KURL& fileURL );
			bool loadFromMedia( const QString& mediaPath, unsigned streamIndex );
			bool save( const KURL& fileURL, bool overwrite ) const;

			void reset();

			inline unsigned channelsCount() const
			{
				return m_channelsCount;
			};

			inline unsigned samplesCount() const // in milliseconds
			{
				return m_samplesCount;
			};

			inline unsigned samplesInterval() const // in milliseconds
			{
				return m_samplesInterval;
			};

			inline Time length() const // in milliseconds
			{
				return m_samplesCount*m_samplesInterval;
			};

			/// warning!! no checks performed!
			inline double dataBySample( unsigned channel, unsigned sample ) const
			{
				//return sample >= m_samplesCount ? 0 : m_samplesData[m_samplesCount*channel+sample];
				return m_samplesData[m_samplesCount*channel+sample];
			};

			inline double dataByPosition( unsigned channel, const Time& position ) const
			{
				int dataIndex = m_samplesCount*channel+position.toMillis()/m_samplesInterval;
				return dataIndex > m_lastDataIndex ? 0 : m_samplesData[dataIndex];
			};

			inline unsigned sampleForPosition( const Time& position ) const
			{
				if ( position > length() )
					return m_samplesCount - 1;

				return position.toMillis()/m_samplesInterval;
			};

		signals:

			void loadProgress( int percentage );

		private:

			unsigned m_channelsCount;
			unsigned m_samplesInterval;
			unsigned m_samplesCount;
			double* m_samplesData;
			int m_lastDataIndex;
			KURL m_mediaURL;
	};
}

#endif
